@@ -46,11 +46,10 @@
 
 #define YELP_FACTORY_OAFIID "OAFIID:GNOME_Yelp_Factory"
 
-static poptContext  poptCon;
-/* static gint         next_opt; */
 static gchar       *cache_dir;
 static gchar       *open_urls;
 static gchar       *startup_id;
+static gchar       **files;
 
 /*structure defining command line option.*/
 enum {
@@ -81,25 +80,28 @@ static gboolean	      main_restore_session    (void);
 static Time slowly_and_stupidly_obtain_timestamp (Display *xdisplay);
 
 
-static struct poptOption options[] = {
+static const GOptionEntry options[] = {
 	{
 		"open-urls",
 		'\0',
-		POPT_ARG_STRING | POPT_ARGFLAG_DOC_HIDDEN,
+		G_OPTION_FLAG_HIDDEN,
+		G_OPTION_ARG_STRING,
 		&open_urls,
-		OPTION_OPEN_URLS,
 		NULL, NULL,
 	},
 	{
 		"with-cache-dir",
 		'\0',
-		POPT_ARG_STRING,
+		0, 
+		G_OPTION_ARG_STRING,
 		&cache_dir,
-		OPTION_CACHE_DIR,
 		N_("Define which cache directory to use"),
 		NULL,
 	},
-	POPT_TABLEEND
+	{ G_OPTION_REMAINING, 
+	  0, 0, G_OPTION_ARG_FILENAME_ARRAY, 
+	  &files, NULL,  NULL },
+	{ NULL}
 };
 
 static BonoboObject *
@@ -350,7 +352,7 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
 		XChangeProperty (xdisplay, 
 				 xwindow, atom_name,
 				 atom_type,
-				 8, PropModeReplace, name, strlen (name));
+				 8, PropModeReplace, (guchar *) name, strlen (name));
 	}
 	
 	XWindowEvent (xdisplay,
@@ -371,8 +373,8 @@ main (int argc, char **argv)
 	gchar         *url = NULL;
 	GnomeClient   *client;
 	gboolean       session_started = FALSE;
-	const gchar  **args;
 	gchar *local_id;
+	GOptionContext *context;
 
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);  
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -385,13 +387,18 @@ main (int argc, char **argv)
 		putenv ("DESKTOP_STARTUP_ID=");
 	}
 
+	/* Commandline parsing is done here */
+	context = g_option_context_new (_(" GNOME Help Browser"));
+
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
 	gtk_window_set_auto_startup_notification(FALSE);
 
 	program = gnome_program_init (PACKAGE, VERSION,
 				      LIBGNOMEUI_MODULE, argc, argv,
-				      GNOME_PARAM_POPT_TABLE, options,
-				      GNOME_PROGRAM_STANDARD_PROPERTIES,
-				      NULL);
+				      GNOME_PROGRAM_STANDARD_PROPERTIES, 
+				      GNOME_PARAM_GOPTION_CONTEXT, context,
+				      GNOME_PARAM_NONE);
 	if (!startup_id) {
 		Time tmp;
 		tmp = slowly_and_stupidly_obtain_timestamp (gdk_display);
@@ -408,18 +415,14 @@ main (int argc, char **argv)
 
 	gnome_vfs_init ();
 
-	yelp_html_initialize ();
+	if (!yelp_html_initialize ()) {
+		g_print ("Could not initialize gecko!");
+		exit (2);
+	}
 
-	/* Commandline parsing is done here */
-	g_object_get (G_OBJECT (program),
-		      GNOME_PARAM_POPT_CONTEXT, &poptCon,
-		      NULL);
-
-	args = poptGetArgs (poptCon);
-	if (args) {
-		url = g_strdup (*args);
-	} else {
-		url = g_strdup ("");
+	if (files != NULL && files[0] != NULL) {
+		url = g_strdup (files[0]);
+		g_strfreev (files);
 	}
 
 	client = gnome_master_client ();
@@ -474,5 +477,8 @@ main (int argc, char **argv)
 		main_start (url);
 	}
 
+	yelp_html_shutdown ();
+
+	g_object_unref (program);
         return 0;
 }
